import { isInternal, toAbsolute } from '#p/util/path.js';
import { load, resolveEntry } from '#p/util/plugin.js';
export const resolveDependencies = async (config, options) => {
    const { reporter } = config;
    const { configFileDir } = options;
    const resolve = (specifier) => resolveEntry(options, specifier);
    const reporters = reporter ? new Set([reporter]) : new Set();
    if (reporter === 'cypress-multi-reporters' && config.reporterOptions?.configFile) {
        const { configFile } = config.reporterOptions;
        const configFilePath = toAbsolute(configFile, configFileDir);
        if (isInternal(configFilePath)) {
            const reporterConfig = await load(configFilePath);
            if (typeof reporterConfig === 'object' && reporterConfig.reporterEnabled) {
                const { reporterEnabled: reporterConcatenatedNames } = reporterConfig;
                const reporterNames = reporterConcatenatedNames.split(',');
                for (const reporterName of reporterNames) {
                    reporters.add(resolve(reporterName.trim()));
                }
            }
        }
    }
    return [...reporters];
};
