import { hasDependency, resolveEntry } from '#p/util/plugin.js';
import { join } from '../../util/path.js';
import { toEntryPattern } from '../../util/protocols.js';
const title = 'React Cosmos';
const enablers = ['react-cosmos'];
const isEnabled = ({ dependencies }) => hasDependency(dependencies, enablers);
const config = ['cosmos.config.json'];
const ext = '{js,jsx,ts,tsx,md,mdx}';
const fixtureEntry = [`**/*.fixture.${ext}`, `__fixtures__/**/*.${ext}`, `**/fixture.${ext}`];
const decoratorEntry = ['**/cosmos.decorator.{jsx,tsx}'];
const entry = [...fixtureEntry, ...decoratorEntry];
const resolveEntryPaths = async (localConfig) => {
    const { fixturesDir, fixtureFileSuffix } = localConfig;
    const entries = [
        join(fixturesDir ?? '__fixtures__', `**/*.${ext}`),
        join(fixturesDir ?? '', `**/*.${fixtureFileSuffix ?? 'fixture'}.${ext}`),
        join(fixturesDir ?? '', `**/${fixtureFileSuffix ?? 'fixture'}.${ext}`),
    ];
    return [...entries, ...decoratorEntry].map(toEntryPattern);
};
const resolveConfig = async (localConfig, options) => {
    const dependencies = (localConfig?.plugins ?? []).map(specifier => resolveEntry(options, specifier));
    return [...dependencies];
};
export default {
    title,
    enablers,
    isEnabled,
    config,
    entry,
    resolveConfig,
    resolveEntryPaths,
};
